EXPORTS
	??1CTTMSGraphicsStep@@UAE@XZ @ 1 NONAME ; CTTMSGraphicsStep::~CTTMSGraphicsStep(void)
	?ResetCounter@CTGraphicsBase@@IAEXH@Z @ 2 NONAME ; void CTGraphicsBase::ResetCounter(int)
	?MultipleResultsForSameID@CTTMSGraphicsStep@@QAEXH@Z @ 3 NONAME ; void CTTMSGraphicsStep::MultipleResultsForSameID(int)
	?ColorModeName@CTGraphicsBase@@SAABVTDesC16@@W4TDisplayMode@@@Z @ 4 NONAME ; class TDesC16 const & CTGraphicsBase::ColorModeName(enum TDisplayMode)
	??0CTGraphicsBase@@QAE@PAVCTestStep@@@Z @ 5 NONAME ; CTGraphicsBase::CTGraphicsBase(class CTestStep *)
	?TestComplete@CTGraphicsBase@@IAEXXZ @ 6 NONAME ; void CTGraphicsBase::TestComplete(void)
	?NewL@CTHashReferenceImages@@SAPAV1@PAVCTestStep@@PAVRFbsSession@@PBVTDesC16@@@Z @ 7 NONAME ; class CTHashReferenceImages * CTHashReferenceImages::NewL(class CTestStep *, class RFbsSession *, class TDesC16 const *)
	?doTestStepL@CTGraphicsStep@@MAE?AW4TVerdict@@XZ @ 8 NONAME ; enum TVerdict CTGraphicsStep::doTestStepL(void)
	?CompareHashValuesL@CTHashReferenceImages@@QAEXABVTDesC16@@@Z @ 9 NONAME ; void CTHashReferenceImages::CompareHashValuesL(class TDesC16 const &)
	?SetSelfDrive@CTGraphicsBase@@IAEXH@Z @ 10 NONAME ; void CTGraphicsBase::SetSelfDrive(int)
	?SetScreenDeviceAndBitmap@CTHashReferenceImages@@QAEXPAVCBitmapDevice@@PAVCFbsBitmap@@PAVCFbsBitGc@@@Z @ 11 NONAME ; void CTHashReferenceImages::SetScreenDeviceAndBitmap(class CBitmapDevice *, class CFbsBitmap *, class CFbsBitGc *)
	?RunTestCaseLeft@CTGraphicsBase@@EAEHH@Z @ 12 NONAME ; int CTGraphicsBase::RunTestCaseLeft(int)
	?CaseComplete@CTGraphicsBase@@IAEXXZ @ 13 NONAME ; void CTGraphicsBase::CaseComplete(void)
	?MQCTest@CTTMSGraphicsStep@@QAEXHPBEH@Z @ 14 NONAME ; void CTTMSGraphicsStep::MQCTest(int, unsigned char const *, int)
	??0CTTMSGraphicsStep@@QAE@XZ @ 15 NONAME ; CTTMSGraphicsStep::CTTMSGraphicsStep(void)
	?MQCTestL@CTTMSGraphicsStep@@QAEXHPBEH@Z @ 16 NONAME ; void CTTMSGraphicsStep::MQCTestL(int, unsigned char const *, int)
	?GenerateHashAndReturnInHexFormatL@CTHashReferenceImages@@QAEXAAVTDes16@@@Z @ 17 NONAME ; void CTHashReferenceImages::GenerateHashAndReturnInHexFormatL(class TDes16 &)
	??1CTHashReferenceImages@@UAE@XZ @ 18 NONAME ; CTHashReferenceImages::~CTHashReferenceImages(void)
	?CloseTMSGraphicsStep@CTTMSGraphicsStep@@QAEXXZ @ 19 NONAME ; void CTTMSGraphicsStep::CloseTMSGraphicsStep(void)
	?CopyScreenToBitmapL@CTHashReferenceImages@@QAEXABVTDesC16@@@Z @ 20 NONAME ; void CTHashReferenceImages::CopyScreenToBitmapL(class TDesC16 const &)
	?RotationName@CTGraphicsBase@@SAABVTDesC16@@W4TGraphicsOrientation@CFbsBitGc@@@Z @ 21 NONAME ; class TDesC16 const & CTGraphicsBase::RotationName(enum CFbsBitGc::TGraphicsOrientation)
	?RecordTestResultL@CTTMSGraphicsStep@@QAEXXZ @ 22 NONAME ; void CTTMSGraphicsStep::RecordTestResultL(void)
	?SetTestStepID@CTTMSGraphicsStep@@QAEXABVTDesC16@@@Z @ 23 NONAME ; void CTTMSGraphicsStep::SetTestStepID(class TDesC16 const &)
	??1CTGraphicsBase@@UAE@XZ @ 24 NONAME ; CTGraphicsBase::~CTGraphicsBase(void)
	?SaveScreenShotL@CTGraphicsBase@@SAXPAVCFbsScreenDevice@@@Z @ 25 NONAME ; void CTGraphicsBase::SaveScreenShotL(class CFbsScreenDevice *)
	?GenerateHashIdStringLC@CTHashReferenceImages@@QAEPAVHBufC16@@ABVTDesC16@@HQBVTPtrC16@@HHH@Z @ 26 NONAME ; class HBufC16 * CTHashReferenceImages::GenerateHashIdStringLC(class TDesC16 const &, int, class TPtrC16 const * const, int, int, int)
	?SetOverallTestStepID@CTTMSGraphicsStep@@QAEXABVTDesC16@@@Z @ 27 NONAME ; void CTTMSGraphicsStep::SetOverallTestStepID(class TDesC16 const &)
	?MQCTestWithErrorCode@CTTMSGraphicsStep@@QAEXHHPBEH@Z @ 28 NONAME ; void CTTMSGraphicsStep::MQCTestWithErrorCode(int, int, unsigned char const *, int)

